import Vue from 'vue'
import Router from 'vue-router'
import Layout from '@/layout'

Vue.use(Router)

/* Layout */

/**
 * hidden: true                   当设置 true 的时候该路由不会在侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1 (默认 false)
 *
 * 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 * 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 * 若你想不管路由下面的 children 声明的个数都显示你的根路由
 * 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * alwaysShow: true
 *
 * redirect: noRedirect           当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'             设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    roles: ['admin','editor']    设置该路由进入的权限，支持多个权限叠加
    title: 'title'               设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'             设置该路由的图标
    breadcrumb: false            如果设置为false，则不会在breadcrumb面包屑中显示(默认 true)
    activeMenu: '/example/list'  当路由设置了该属性，则会高亮相对应的侧边栏
  }
 showFather: 'true' or 'false' 是否一定显示父节点
 */

/**
 * 不需要动态判断权限的路由
 * 基础页面，所有人可以访问
 */
export const constantRoutes = [
  {
    path: '/reSetPsw',
    component: Layout,
    name: 'reSetPsw',
    hidden: true,
    redirect: '/reSetPsw/index',
    children: [{
      path: '/reSetPsw/index',
      name: 'reSetPswDetail',
      component: () => import('@/views/reSetPsw.vue'),
      meta: { title: '修改密码', icon: 'dashboard' }
    }]
  },
  {
    path: '/',
    redirect: '/projectInfo/index'
  },
  {
    path: '/login',
    component: () => import('@/views/user/login'),
    hidden: true
  },
  {
    path: '/list/demo',
    name: 'LISTDEMO',
    component: () => import('@/layout/index'),
    meta: { title: '合同管理' },
    children: [
      {
        path: '/admin/list/index',
        name: 'LISTINDEX',
        component: () => import('@/views/list/index'),
        meta: { title: '合同管理' }
      },
      {
        path: '/contract/manage1/add',
        name: 'contractManage'.toLocaleUpperCase(),
        component: () => import('@/views/list/add'),
        meta: { title: '合同信息' }
      },
      {
        path: '/contract/manage1/addSecond',
        name: 'contractManage'.toLocaleUpperCase(),
        component: () => import('@/views/list/addSecond'),
        meta: { title: '合同信息' }
      },
      {
        path: '/contract/manage1/addThird',
        name: 'contractManage'.toLocaleUpperCase(),
        component: () => import('@/views/list/addThird'),
        meta: { title: '合同信息' }
      },
      {
        path: '/contract/manage1/addFourth',
        name: 'contractManage'.toLocaleUpperCase(),
        component: () => import('@/views/list/addFourth'),
        meta: { title: '合同信息' }
      },
      {
        path: '/contract/manage1/addFifth',
        name: 'contractManage'.toLocaleUpperCase(),
        component: () => import('@/views/list/addFifth'),
        meta: { title: '合同信息' }
      },
      {
        path: '/contract/manage1/addSixth',
        name: 'contractManage'.toLocaleUpperCase(),
        component: () => import('@/views/list/addSixth'),
        meta: { title: '合同信息' }
      },
      {
        path: '/contract/manage1/addSeventh',
        name: 'contractManage'.toLocaleUpperCase(),
        component: () => import('@/views/list/addSeventh'),
        meta: { title: '合同信息' }
      }
    ]
  },
  {
    path: '/personnel',
    name: 'Personnel',
    meta: { title: '人员情况' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/personnel/index',
        name: 'Personnel'.toLocaleUpperCase(),
        meta: { title: '人员情况' },
        component: () => import('@/views/personnel/index')
      }
    ]
  },
  {
    path: '/administrative',
    name: 'Administrative',
    meta: { title: '行政组织' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/administrative/index',
        name: 'Administrative'.toLocaleUpperCase(),
        meta: { title: '行政组织' },
        component: () => import('@/views/administrative/index')
      }
    ]
  },
  {
    path: '/accounting',
    name: 'Accounting',
    meta: { title: '核算组织' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/accounting/index',
        name: 'Accounting'.toLocaleUpperCase(),
        meta: { title: '核算组织' },
        component: () => import('@/views/accounting/index')
      }
    ]
  },
  {
    path: '/contactsUnit',
    name: 'ContactsUnit',
    meta: { title: '往来单位' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/contactsUnit/index',
        name: 'ContactsUnit'.toLocaleUpperCase(),
        meta: { title: '往来单位' },
        component: () => import('@/views/contactsUnit/index')
      },
      {
        path: '/contactsUnit/contactsUnitDetails',
        name: 'ContactsUnit'.toLocaleUpperCase(),
        component: () => import('@/views/contactsUnit/contactsUnitDetails'),
        meta: { title: '往来单位查看' }
      }
    ]
  },
  {
    path: '/projectInfo',
    name: 'ProjectInfo',
    meta: { title: '项目信息' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/projectInfo/index',
        name: 'ProjectInfo'.toLocaleUpperCase(),
        meta: { title: '项目信息' },
        component: () => import('@/views/projectInfo/index')
      },
      {
        path: '/projectInfo/addProject',
        name: 'AddProject'.toLocaleUpperCase(),
        component: () => import('@/views/projectInfo/addProject'),
        meta: { title: '项目信息' }
      }
    ]
  },
  {
    path: '/assetsInfo',
    name: 'AssetsInfo',
    meta: { title: '资产信息' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/assetsInfo/index',
        name: 'AssetsInfo'.toLocaleUpperCase(),
        meta: { title: '资产信息' },
        component: () => import('@/views/assetsInfo/index')
      },
      {
        path: '/assetsInfo/add',
        name: 'AssetsInfo'.toLocaleUpperCase(),
        component: () => import('@/views/assetsInfo/add'),
        meta: { title: '资产信息' }
      }
    ]
  },
  {
    path: '/materialsInfo',
    name: 'MaterialsInfo',
    meta: { title: '物资设备编码信息' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/materialsInfo/index',
        name: 'MaterialsInfo'.toLocaleUpperCase(),
        meta: { title: '物资设备编码信息' },
        component: () => import('@/views/materialsInfo/index')
      },
      {
        path: '/materialsInfo/details',
        name: 'MaterialsInfo'.toLocaleUpperCase(),
        meta: { title: '查看物资设备编码信息' },
        component: () => import('@/views/materialsInfo/details')
      }
    ]
  },
  {
    path: '/materialsClassify',
    name: 'materialsClassify',
    meta: { title: '物资设备分类信息' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/materialsClassify/details',
        name: 'materialsClassify'.toLocaleUpperCase(),
        meta: { title: '查看物资设备分类信息' },
        component: () => import('@/views/materialsClassify/details')
      },
      {
        path: '/materialsClassify/index',
        name: 'materialsClassify'.toLocaleUpperCase(),
        meta: { title: '物资设备分类信息' },
        component: () => import('@/views/materialsClassify/index')
      }
    ]
  },
  {
    path: '/financial',
    name: 'Financial',
    meta: { title: '金融机构' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/financial/index',
        name: 'Financial'.toLocaleUpperCase(),
        meta: { title: '金融机构' },
        component: () => import('@/views/financial/index')
      }
    ]
  },
  {
    path: '/dataDictionary',
    name: 'DataDictionary',
    meta: { title: '数据字典' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/dataDictionary/index',
        name: 'DataDictionary'.toLocaleUpperCase(),
        meta: { title: '数据字典' },
        component: () => import('@/views/dataDictionary/index')
      }
    ]
  },
  {
    path: '/userInfo',
    name: 'UserInfo',
    meta: { title: '用户信息' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/userInfo/index',
        name: 'UserInfo'.toLocaleUpperCase(),
        meta: { title: '用户信息' },
        component: () => import('@/views/userInfo/index')
      }
    ]
  },
  {
    path: '/journal/list',
    name: 'journalList'.toLocaleUpperCase(),
    meta: { title: '日志管理' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/journalManage/index',
        name: 'AdminList'.toLocaleUpperCase(),
        meta: { title: '日志管理' },
        component: () => import('@/views/journalManage/index')
      }
    ]
  }, {
    path: '/journal/list',
    name: 'journalList'.toLocaleUpperCase(),
    meta: { title: '同步日志' },
    component: () => import('@/layout/index'),
    children: [
      {
        path: '/synchronizationJournal/index',
        name: 'SynchronizationJournal'.toLocaleUpperCase(),
        meta: { title: '同步日志' },
        component: () => import('@/views/synchronizationJournal/index')
      }
    ]
  },
  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  }
]

/**
 * 有权限的路由
 * 需要动态判断权限并通过 addRoutes 动态添加的页面。
 */
export const asyncRoutes = [
  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
